@@ -364,23 +364,22 @@ The sound files provides by this portion are taken from:
 """
 import os
 import re
-import shutil
 
 from abc import ABC, abstractmethod
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type
 
-from ae.base import NAME_PARTS_SEP, duplicates, now_str, snake_to_camel  # type: ignore
-from ae.paths import Collector, norm_path, path_folders                                 # type: ignore
-from ae.updater import check_all                                                        # type: ignore
-from ae.inspector import stack_var                                                      # type: ignore
-from ae.files import FilesRegister, RegisteredFile                                      # type: ignore
-from ae.i18n import default_language, load_language_texts, register_translations_path   # type: ignore
-from ae.core import DEBUG_LEVELS, registered_app_names                                  # type: ignore
-from ae.console import ConsoleApp                                                       # type: ignore
+from ae.base import NAME_PARTS_SEP, duplicates, now_str, snake_to_camel                             # type: ignore
+from ae.files import RegisteredFile                                                                 # type: ignore
+from ae.paths import copy_file, copy_tree, norm_path, path_folders, Collector, FilesRegister        # type: ignore
+from ae.updater import check_all                                                                    # type: ignore
+from ae.inspector import stack_var                                                                  # type: ignore
+from ae.i18n import default_language, load_language_texts, register_translations_path               # type: ignore
+from ae.core import DEBUG_LEVELS, registered_app_names                                              # type: ignore
+from ae.console import ConsoleApp                                                                   # type: ignore
 
 
-__version__ = '0.1.60'
+__version__ = '0.1.61'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -685,19 +684,16 @@ class MainAppBase(ConsoleApp, ABC):
         backup_root = norm_path("{ado}") + now_str(sep="_")
         os.makedirs(backup_root)
 
-        copy_function = shutil.copy     # copy2 crashes on 'android' (see https://bugs.python.org/issue28141)
-
         coll = Collector()
         app_configs = tuple(ana + "." + ext for ana in registered_app_names() for ext in ('ini', 'cfg'))
         coll.collect("{ado}", "{usr}", "{cwd}", append=app_configs, only_first_of='prefix')
         for file in coll.files:
-            if not os.path.exists(os.path.basename(file)):  # don't overwrite the first one found (the active one)
-                copy_function(file, backup_root)
+            copy_file(file, os.path.join(backup_root, os.path.basename(file)))
 
         coll = Collector(path_scanner=path_folders)
         coll.collect("{ado}", "{cwd}", append=('img', 'loc', 'snd'), only_first_of='prefix')
         for path in coll.paths:
-            shutil.copytree(path, os.path.join(backup_root, os.path.basename(path)), copy_function=copy_function)
+            copy_tree(path, os.path.join(backup_root, os.path.basename(path)))
 
         return backup_root
 
